@@ -27,7 +27,7 @@ pub struct Command {
     pub dry_run: bool,
 
     /// URL of the Fuel Client Node
-    #[clap(env = "FUEL_NODE_URL", default_value = "127.0.0.1:4000")]
+    #[clap(env = "FUEL_NODE_URL", default_value = "http://127.0.0.1:4000")]
     pub node_url: String,
 
     /// Kill Fuel Node Client after running the code.
