@@ -1,5 +1,4 @@
-#![allow(dead_code)]
-mod cli;
+pub mod cli;
 mod ops;
 mod utils;
 
@@ -11,6 +10,5 @@ pub mod test {
 
 #[cfg(feature = "util")]
 pub mod util {
-    pub use crate::utils::client::start_fuel_core;
     pub use sway_utils::constants;
 }
