@@ -30,12 +30,10 @@ name = "{project_name}"
 version = "0.1.0"
 
 [dependencies]
-fuel-gql-client = {{ version = "0.5", default-features = false }}
-fuel-tx = "0.7"
-fuels-abigen-macro = "0.9"
-fuels-contract = "0.9"
-fuels-core = "0.9"
-fuels-signers = "0.9"
+fuel-gql-client = {{ version = "0.6", default-features = false }}
+fuel-tx = "0.9"
+fuels-abigen-macro = "0.10"
+fuels = "0.10"
 rand = "0.8"
 tokio = {{ version = "1.12", features = ["rt", "macros"] }}
 
@@ -99,8 +97,8 @@ pub(crate) fn default_test_program(project_name: &str) -> String {
         "{}{}{}{}{}",
         r#"use fuel_tx::{ContractId, Salt};
 use fuels_abigen_macro::abigen;
-use fuels_contract::{contract::Contract, parameters::TxParameters};
-use fuels_signers::util::test_helpers;
+use fuels::prelude::*;
+use fuels::test_helpers;
 
 // Load abi from json
 abigen!(MyContract, "out/debug/"#,
